@@ -22,31 +22,7 @@
 #include <linux/magic.h>
 
 #include <rt-utils.h>
-
-#ifdef __i386__
-#ifndef __NR_sched_setattr
-#define __NR_sched_setattr		351
-#endif
-#ifndef __NR_sched_getattr
-#define __NR_sched_getattr		352
-#endif
-#ifndef __NR_getcpu
-#define __NR_getcpu			309
-#endif
-#else /* x86_64 */
-#ifndef __NR_sched_setattr
-#define __NR_sched_setattr		314
-#endif
-#ifndef __NR_sched_getattr
-#define __NR_sched_getattr		315
-#endif
-#ifndef __NR_getcpu
-#define __NR_getcpu			309
-#endif
-#endif /* i386 or x86_64 */
-#ifndef SCHED_DEADLINE
-#define SCHED_DEADLINE		6
-#endif
+#include <rt-sched.h>
 
 #define _STR(x) #x
 #define STR(x) _STR(x)
@@ -57,11 +33,6 @@
 #define CPUSET_ALL	"my_cpuset_all"
 #define CPUSET_LOCAL	"my_cpuset"
 
-#define gettid() syscall(__NR_gettid)
-#define sched_setattr(pid, attr, flags) syscall(__NR_sched_setattr, pid, attr, flags)
-#define sched_getattr(pid, attr, size, flags) syscall(__NR_sched_getattr, pid, attr, size, flags)
-#define getcpu(cpup, nodep, unused) syscall(__NR_getcpu, cpup, nodep, unused)
-
 typedef unsigned long long u64;
 typedef unsigned int u32;
 typedef int s32;
@@ -115,24 +86,6 @@ struct sched_data {
 	char buff[BUFSIZ+1];
 };
 
-struct sched_attr {
-	u32 size;
-
-	u32 sched_policy;
-	u64 sched_flags;
-
-	/* SCHED_NORMAL, SCHED_BATCH */
-	s32 sched_nice;
-
-	/* SCHED_FIFO, SCHED_RR */
-	u32 sched_priority;
-
-	/* SCHED_DEADLINE */
-	u64 sched_runtime;
-	u64 sched_deadline;
-	u64 sched_period;
-};
-
 static int shutdown;
 
 static pthread_barrier_t barrier;
@@ -678,8 +631,16 @@ static void usage(char **argv)
 		p--;
 	p++;
 
-	printf("usage: %s\n"
-	       "\n",p);
+	printf("usage: %s [options]\n"
+	       " -h - Show this help menu\n"
+	       " -a - Use all CPUs\n"
+	       " -c cpulist - Comma/hyphen separated list of CPUs to run deadline tasks on\n"
+	       " -i interval(us) - The shortest deadline for the tasks (default 1000us)\n"
+	       " -s step(us) - The amount to increase the deadline for each task (default 500us)\n"
+	       " -t threads - The number of threads to run as deadline (default 1)\n"
+	       " -D time - Specify a length for the test run\n"
+	       "           Append 'm', 'h', or 'd' to specify minutes, hours or days\n"
+	       "\n", p);
 	exit(-1);
 }
 
@@ -800,7 +761,7 @@ void *run_deadline(void *data)
 	attr.sched_runtime = sd->runtime_us * 1000;
 	attr.sched_deadline = sd->deadline_us * 1000;
 
-	printf("thread[%ld] runtime=%lldus deadline=%lldus\n",
+	printf("thread[%d] runtime=%lldus deadline=%lldus\n",
 	       gettid(), sd->runtime_us, sd->deadline_us);
 
 	pthread_barrier_wait(&barrier);
@@ -1204,7 +1165,6 @@ int main (int argc, char **argv)
 		exit(-1);
 	}
 
-	all_cpus = 1;
 	if (!all_cpus) {
 		int *pids;
 
@@ -1240,13 +1200,14 @@ int main (int argc, char **argv)
 		system("cat /sys/fs/cgroup/cpuset/my_cpuset/tasks");
 	}
 
-	printf("main thread %ld\n", gettid());
+	printf("main thread %d\n", gettid());
 
 	pthread_barrier_wait(&barrier);
-	printf("fail 2 %d\n", fail);
 
-	if (fail)
+	if (fail) {
+		printf("fail 2\n");
 		exit(-1);
+	}
 
 	pthread_barrier_wait(&barrier);
 
