@@ -44,8 +44,6 @@
 #include "rt-get_cpu.h"
 #include "error.h"
 
-#define gettid() syscall(__NR_gettid)
-
 #define USEC_PER_SEC 1000000
 
 #define SEM_WAIT_FOR_RECEIVER 0
@@ -187,7 +185,7 @@ void *semathread(void *param)
 				char tracing_enabled_file[MAX_PATH];
 
 				strcpy(tracing_enabled_file, get_debugfileprefix());
-				strcat(tracing_enabled_file, "tracing_enabled");
+				strcat(tracing_enabled_file, "tracing_on");
 				int tracing_enabled =
 				    open(tracing_enabled_file, O_WRONLY);
 				if (tracing_enabled >= 0) {
